from django.db import models
from django.core.exceptions import ValidationError
from django.urls import reverse

def validate_isbn(input):
    if len(str(input)) != 13:
        raise ValidationError('ISBN is not 13 digits.')

class Author(models.Model):
    first_name = models.CharField(max_length=100,default="")
    last_name = models.CharField(max_length=100,default="")
    age = models.IntegerField(default=0)
    nationality = models.CharField(max_length=50,default="")
    bio = models.TextField(max_length=700,default="")

    def __str__(self):
        return '{} {}'.format(self.first_name, self.last_name)

    def get_absolute_url(self):
        return reverse('bookshelf:author_details', kwargs={'pk': self.pk})
    

class Books(models.Model):
    title = models.CharField(max_length=50,default="")
    author = models.ForeignKey(Author,on_delete=models.CASCADE)
    publisher = models.CharField(max_length=100,default="")
    year_published = models.IntegerField(default=2023)
    ISBN = models.IntegerField(validators=[validate_isbn],unique=True,default=0000000000000)
    blurb = models.TextField(max_length=200,default="")

    def __str__(self):
        return '{} by {} {}'.format(self.title, self.author.first_name, self.author.last_name)
    
    def get_absolute_url(self):
        return reverse('bookshelf:book_details', kwargs={'pk': self.pk})
    